/*
 * Copyright 2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

#include "fsl_debug_console.h"
#include "board.h"

#include "fsl_iap.h"

#include "fsl_common.h"
#include "pin_mux.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define DEMO_IAP_EEPROM_WRITE_ENABLE_CLOCK() (CLOCK_EnableClock(kCLOCK_Eeprom))

/*******************************************************************************
 * Prototypes
 ******************************************************************************/

#define EEPROM_PAGE_SIZE (FSL_FEATURE_EEPROM_SIZE / FSL_FEATURE_EEPROM_PAGE_COUNT)

/*******************************************************************************
 * Variables
 ******************************************************************************/

static uint32_t s_PageBuf[EEPROM_PAGE_SIZE / sizeof(uint32_t)];

/*******************************************************************************
 * Code
 ******************************************************************************/

/*!
* @brief Main function
*/
int main(void)
{
    uint32_t status;

    /* Board pin, clock, debug console init */
    /* attach 12 MHz clock to FLEXCOMM0 (debug console) */
    CLOCK_AttachClk(BOARD_DEBUG_UART_CLK_ATTACH);

    BOARD_InitPins_Core0();
    BOARD_BootClockFROHF48M();
    BOARD_InitDebugConsole();

    PRINTF("\f\r\nIAP EEPROM example\r\n");

    /* Read EEPROM */
    PRINTF("\r\nRead EEPROM sector 1\r\n");
    status = IAP_ReadEEPROMPage(1, s_PageBuf, SystemCoreClock);
    if (status != kStatus_IAP_Success)
    {
        PRINTF("\r\nRead EEPROM Page failed\r\n");
    }

    /* Enable the EEPROM clock */
    DEMO_IAP_EEPROM_WRITE_ENABLE_CLOCK();
    memset(s_PageBuf, 0, 128);

    /* Write EEPROM */
    PRINTF("\r\nWrite EEPROM sector 1\r\n");
    status = IAP_WriteEEPROMPage(1, s_PageBuf, SystemCoreClock);
    if (status != kStatus_IAP_Success)
    {
        PRINTF("\r\nWrite EEPROM Page failed\r\n");
    }

    PRINTF("\r\nEnd of IAP EEPROM Example\r\n");
    while (1)
    {
    }
}
